package com.ruoyi.zongzhi.service;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcDengbaoSystem;

/**
 * 等保系统Service接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface ITcDengbaoSystemService 
{
    /**
     * 查询等保系统
     * 
     * @param id 等保系统主键
     * @return 等保系统
     */
    public TcDengbaoSystem selectTcDengbaoSystemById(Long id);

    /**
     * 查询等保系统列表
     * 
     * @param tcDengbaoSystem 等保系统
     * @return 等保系统集合
     */
    public List<TcDengbaoSystem> selectTcDengbaoSystemList(TcDengbaoSystem tcDengbaoSystem);

    /**
     * 新增等保系统
     * 
     * @param tcDengbaoSystem 等保系统
     * @return 结果
     */
    public int insertTcDengbaoSystem(TcDengbaoSystem tcDengbaoSystem);

    /**
     * 修改等保系统
     * 
     * @param tcDengbaoSystem 等保系统
     * @return 结果
     */
    public int updateTcDengbaoSystem(TcDengbaoSystem tcDengbaoSystem);

    /**
     * 批量删除等保系统
     * 
     * @param ids 需要删除的等保系统主键集合
     * @return 结果
     */
    public int deleteTcDengbaoSystemByIds(Long[] ids);

    /**
     * 删除等保系统信息
     * 
     * @param id 等保系统主键
     * @return 结果
     */
    public int deleteTcDengbaoSystemById(Long id);
}
